pub fn admin_target_principal(req: &AdminRequestKind) -> Option<&PrincipalId>Expand description
Borrow the target principal for audit purposes — Some only when the
request operates on a principal distinct from the caller.
pub fn admin_target_principal(req: &AdminRequestKind) -> Option<&PrincipalId>Borrow the target principal for audit purposes — Some only when the
request operates on a principal distinct from the caller.