pub fn required_capability(
request: &KernelRequest,
scope: AuthorityScope,
) -> &'static strExpand description
Return the static capability required to satisfy request under scope.
pub fn required_capability(
request: &KernelRequest,
scope: AuthorityScope,
) -> &'static strReturn the static capability required to satisfy request under scope.